#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-HHsJZZGYUAaCyNUFf9t5Ep
key:                  coinbase-pro-0.9.3.2-HHsJZZGYUAaCyNUFf9t5Ep
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  0ecc8d8e8aa316ff9b645b24970a12fe
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-HHsJZZGYUAaCyNUFf9t5Ep
depends:
    HsOpenSSL-0.11.7.9-Ko1iFKMHkcSR9zsBHmd8A
    aeson-2.2.2.0-Dt9IcEbIPgo3pXUjrBlJbR
    aeson-casing-0.2.0.0-5jofmoVF6uR7nivkslWfnt
    async-2.2.6-IB55pRMOICm7lPJ05sVN9d base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-5YMMoJpb9OFJXbZxlbEy82 exceptions-0.10.7
    http-api-data-0.6.1-JDx4qzIgczl11OpNpo9zfV
    http-client-0.7.19-ChmOISdzz1UJcIMHPfAR81
    http-client-tls-0.3.6.4-BD4TqKfIzwr11ySZlgGnkK
    http-streams-0.8.9.9-BEuxqL9B8CLHqYBNw1fJZu
    http-types-0.12.4-LSgWFg4mVle7jKIO2vdgXi
    io-streams-1.5.2.2-1UQD134TFkk1efTMK5hLFs
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-435zy6qxTBGFK5XFFiJsye
    servant-0.20.3.0-WczJZPmgTS245tqPjTGfm
    servant-client-0.20.3.0-1KxETUeXIBv8lsCg6zUcr2
    servant-client-core-0.20.3.0-CVJ6nJUj01f7H1V7HJYIZe
    tasty-1.5.2-9tyUPHiwq7fIOac17jBCXg
    tasty-hunit-0.10.2-1aQPJGmKmQL6O8wlcWrT0t text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-FBIsnBWtT6E7heVlXnOQJJ
    unordered-containers-0.2.20.1-6k45pUyQa13JRvzUHn0wS1
    uuid-1.3.16.1-HIa20R8ru6u8D3acs3Ctff
    vector-0.13.2.0-B5QnucNm6YY8XIvh7YleVY
    websockets-0.12.7.3-Btgw9NOiftw5fJkhtb1n6C
    wuss-2.0.1.7-IKupy2NhX1t69HWCcjcsRZ

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

